##################################################
#Peitao Wu (peitaowu@bu.edu)
#Biqi Wang (wangbiqi@bu.edu)
##################################################


####Y1 is binary and Y2 is binary, in this function, we adjust two binary traits (y1 and y3)

###### function for  estimating cov(x,y) x is Snp and y is binary trait (y1, y3)
#####d = Data GWAS summary statistics
#####beta_m_hat = column name for beta coeficient for SNP in y~SNP 
#####maf = column name for minor allele frequency of SNPs
#####N = sample size
#####Ncase = number of cases in y
cov_est <- function(d,beta_m_hat,maf, N, Ncase){
  Nctrl<-N-Ncase
  prev<-Ncase/N
  r<-nrow(d)
  beta_m_hat<-d[,beta_m_hat]
  maf<-d[,maf]
  
  p0<-c()
  p1<-c()
  ## a is the OR of SNP x on Y2, b is the proportion of non-cases(controls), c is the proportion of cases, p is the allele frequency of x
  s<-function(a,b,c,p)
  {
    p1[1]<-(-b+p-a*p-a*c+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
    p1[2]<-(-b+p-a*p-a*c-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
    p0[1]<-(-a*p+p-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
    p0[2]<-(-a*p+p+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
    return(c(p0,p1))
  }
  u<-c()
  for (j in 1:r){
    temp<-s(exp(beta_m_hat[j]),1-prev,prev,maf[j])
    u<-rbind(u,temp)
  }
  u<-u[,c(1,3)]
  a<-c()
  b<-c()
  c<-c()
  d<-c()
  e<-c()
  f<-c()
  for(j in 1:r)
  {
    a[j]<-(1-u[j,1])^2*Nctrl
    c[j]<-2*(1-u[j,1])*u[j,1]*Nctrl
    e[j]<-u[j,1]^2*Nctrl
    
    b[j]<-(1-u[j,2])^2*Ncase
    d[j]<-2*(1-u[j,2])*u[j,2]*Ncase
    f[j]<-u[j,2]^2*Ncase
  }
  est<-cbind(a,c,e,b,d,f)
  est_cov<-c()
  
  for(j in 1:r)
  {
    est_cov[j]<-1/N*(est[j,1]*(2*maf[j])*(prev)+est[j,2]*(1-2*maf[j])*(0-prev)+est[j,3]*(2-2*maf[j])*(0-prev)+est[j,4]*(0-2*maf[j])*(1-prev)
                     +est[j,5]*(1-2*maf[j])*(1-prev)+est[j,6]*(2-2*maf[j])*(1-prev))
  }
  return(est_cov)
}
# library(data.table)
# m1<-fread('/restricted/projectnb/sequencing/biqiwang/cond_phenotype/prevAFcov.summary2.commonv',data.table=F)
# m2<-fread('/restricted/projectnb/sequencing/biqiwang/cond_phenotype/fhs_hrc_gwas/geepack/summary2.HRC.r1.1.gwas.2016/summary2/prevmi.summary2.commonv',data.table=F)
# m22<-fread('/restricted/projectnb/sequencing/biqiwang/cond_phenotype/fhs_hrc_gwas/geepack/summary2.HRC.r1.1.gwas.2016/summary2/prevhf.summary2.commonv',data.table=F)
# m3<-fread('/restricted/projectnb/sequencing/biqiwang/cond_phenotype/afprev.cov.2014.csv',data.table=F)
# names(m1)<-c("Chr","SNPID","Phys_location","phen","N","iMAF","variMAF","Nd","iMAFd","variMAFd","beta","se","chisq","df","model","remark","pval","effect","noneffect","obs_eaf","ratio","input_snp","iwgadiff","iwgafold","inrefgene","refgenes_60kb_from_SNP","closestrefgene","distancefromclosestrefgene")
# names(m2)<-c("Chr","SNPID","Phys_location","phen","N","iMAF","variMAF","Nd","iMAFd","variMAFd","beta","se","chisq","df","model","remark","pval","effect","noneffect","obs_eaf","ratio","input_snp","iwgadiff","iwgafold","inrefgene","refgenes_60kb_from_SNP","closestrefgene","distancefromclosestrefgene")
# names(m22)<-c("Chr","SNPID","Phys_location","phen","N","iMAF","variMAF","Nd","iMAFd","variMAFd","beta","se","chisq","df","model","remark","pval","effect","noneffect","obs_eaf","ratio","input_snp","iwgadiff","iwgafold","inrefgene","refgenes_60kb_from_SNP","closestrefgene","distancefromclosestrefgene")
# com<-merge(m1,m2,by="SNPID")
# com<-merge(com,m22,by="SNPID")
# com <- com[1:100,]
# r <- nrow(com)

#xy1<-cov_est(com,'beta.x', maf = 'iMAF.x',N = 8466,Ncase = 319)*8466
#xy2<-cov_est(com,'beta.y', maf = 'iMAF.x',N = 8168,Ncase = 255)*8168
#xy3<-cov_est(com,'beta', maf = 'iMAF.x',N = 8168,Ncase = 106)*8168

# Estimate the regression coefficient of y2~y1, full
####data = phenotype file include two philetypes
####y2 = column names for dependent phenotype
####y1 column names for phenotype to be adjusted
####cor list of covariants
get_gamma_full_y2_bi <- function(data,y2,y1,cor)
{ 
  if (!is.null(cor)){
    mod4<-summary(glm(as.formula(paste0(y2,'~',y1,'+',paste(cor,collapse = '+'))),data=data,family=binomial))
  }else{
    mod4<-summary(glm(as.formula(paste0(y2,'~',y1)),data=data, family=binomial))
  }
  gamma_hat<-mod4$coefficients[2,1]
  sd_gamma_hat<-mod4$coefficients[2,2]
  return(c(gamma_hat,sd_gamma_hat))
}

#####estimating approximated beta and pvalue using subset
####data = phenotype file include two philetypes
####id = column names for subjects id
####subid = id list for subset
####y2 = column names for dependent phenotype
####y1 column names for phenotype to be adjusted
####cor list of covariants
get_gamma_subset_y2_bi <- function(data,id,subid,y2,y1,cor)
{
  dd <- data[which(data[,id]%in%subid),]
  if (!is.null(cor)){
    mod4<-summary(glm(as.formula(paste0(y2,'~',y1,'+',paste(cor,collapse = '+'))),data=dd, family=binomial))
  }else{
    mod4<-summary(glm(as.formula(paste0(y2,'~',y1)),data=dd, family=binomial))
  }
  gamma_hat<-mod4$coefficients[2,1]
  sd_gamma_hat<-mod4$coefficients[2,2]
  return(c(gamma_hat,sd_gamma_hat))
}


#####example

# m3<-fread('/restricted/projectnb/sequencing/biqiwang/cond_phenotype/afprev.cov.2014.csv',data.table=F)
# get_gamma_full_y2_bi(data =m3,y2 = 'prevAF',y1 = 'prevMI',cor =c('dnaage','sex.x'))
# get_gamma_full_y2_bi(data =m3,y2 = 'prevAF',y1 = 'prevCHF',cor =c('dnaage','sex.x'))
# set.seed(23)
# sub<-m3[sample(1:dim(m3)[1],1000),'id']
# get_gamma_subset_y2_bi(data = m3, id ='id',subid= sub,y2 = 'prevAF', y1 = 'prevMI',cor =c('dnaage','sex.x'))
# get_gamma_subset_y2_bi(data = m3, id ='id',subid= sub,y2 = 'prevAF', y1 = 'prevCHF',cor =c('dnaage','sex.x'))

#####should be matched
#####d = Data with both two phenotypes GWAS summary statistics
#####N = sample size for Y2
#####N2 = sample size for Y1
#####N3 = sample size for Y3
#####Ncase = number of cases in Y2
#####Ncase2 = number of cases in Y1
#####Ncase3 = number of cases in Y3
#####beta_m_hat = column name for beta coeficient for SNP in Y2~SNP
#####sd_beta_m_hat = column name for standard error for beta coeficient of SNP in Y2~SNP
#####eta_hat = column name for beta coeficient for SNP in Y1~SNP
#####sd_eta = column name for standard error for beta coeficient of SNP in Y1~SNP
#####mu_hat = column name for standard error for beta coeficient of SNP in Y3~SNP
#####maf = column name for minor allele frequency of SNPs
#####gamma_hat = slope coefficient estimation in Y2~Y1
#####sd_gamma_hat = slope coefficient estimation in Y2~Y1
#####theta_hat = slope coefficient estimation in Y2~Y1
#####sd_theta_hat = slope coefficient estimation in Y2~Y3
#####y1 column names of Y1
#####y2 column names of Y2
#####y3 column names of Y3
#####data for phenotypes
y1y2_bi <- function(d,data,y1,y2,y3,N2,N3,Ncase2,Ncase3,beta_m_hat,sd_beta_m_hat,eta_hat,sd_eta,mu_hat,sd_mu_hat,maf,N,Ncase,gamma_hat,sd_gamma_hat,theta_hat,sd_theta_hat)
{
  r <- nrow(d)
  xy1<-cov_est(d,beta_m_hat, maf = maf,N = N,Ncase = Ncase)*N
  xy2<-cov_est(d,eta_hat, maf = maf,N = N2,Ncase = Ncase2)*N2
  xy3<-cov_est(d,mu_hat, maf = maf,N = N3,Ncase = Ncase3)*N3
  
  prev<-Ncase/N
  prev2<-Ncase2/N2
  prev3<-Ncase3/N3
  
  beta_m_hat<-d[,beta_m_hat]
  sd_beta_m_hat<-d[,sd_beta_m_hat]
  eta_hat<-d[,eta_hat]
  sd_eta<-d[,sd_eta]
  mu_hat<-d[,mu_hat]
  sd_mu<-d[,sd_mu_hat]
  
  
  maf<-d[,maf]
  xx<-2*maf*(1-maf)*N
  
  y2y2<-N2*prev2*(1-prev2)
  y3y3<-N3*prev3*(1-prev3)
  y1y1<-N*prev*(1-prev)
  
  y1y2<-(table(data[,y2],data[,y1])[1,1]*prev*prev2+table(data[,y2],data[,y1])[1,2]*(0-prev)*(1-prev2)+table(data[,y2],data[,y1])[2,1]*(1-prev)*(0-prev2)+table(data[,y2],data[,y1])[2,2]*(1-prev)*(1-prev2))
  y1y3<-(table(data[,y2],data[,y3])[1,1]*prev*prev3+table(data[,y2],data[,y3])[1,2]*(0-prev)*(1-prev3)+table(data[,y2],data[,y3])[2,1]*(1-prev)*(0-prev3)+table(data[,y2],data[,y3])[2,2]*(1-prev)*(1-prev3))
  y2y3<-(table(data[,y1],data[,y3])[1,1]*prev2*prev3+table(data[,y1],data[,y3])[1,2]*(0-prev2)*(1-prev3)+table(data[,y1],data[,y3])[2,1]*(1-prev2)*(0-prev3)+table(data[,y1],data[,y3])[2,2]*(1-prev2)*(1-prev3))
  
  
  var_beta_m_hat<-sd_beta_m_hat^2
  var_gamma_hat<-sd_gamma_hat^2
  var_theta_hat<-sd_theta_hat^2
  cov12<-c()
  cov13<-c()
  cov23<-c()
  beta_c<-c()
  pval_c<-c()
  var_c<-c()
  z<-c()
  
  for(j in 1:r)
  {
    if(is.na(xy1[j]) | is.na(xy2[j]) | is.na(xy3[j]) |is.na(xx[j]) ){beta_c[j]<-NA;z[j]<-NA;pval_c[j]<-NA}else{
      v<-matrix(c(xx[j],xy2[j],xy3[j],xy2[j],y2y2,y2y3,xy3[j],y2y3,y3y3),nrow=3,ncol=3,byrow=F)
      D<-matrix(c(xx[j],0,0,0,y2y2,0,0,0,y3y3),nrow=3,ncol=3,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat,theta_hat)	
      beta_c[j]<-temp[1]
      cov12[j]<-y1y1/N*xx[j]^(-1)*xy2[j]*(y2y2)^(-1)*sd_beta_m_hat[j]*sd_gamma_hat/(sqrt((xx[j])^(-1)/(N-1)*(y1y1-xy1[j]/xx[j]*xy1[j])*(y2y2)^(-1)/(N-1)*(y1y1-y1y2/y2y2*y1y2)))
      cov13[j]<-y1y1/N*xx[j]^(-1)*xy3[j]*(y3y3)^(-1)*sd_beta_m_hat[j]*sd_theta_hat/(sqrt((xx[j])^(-1)/(N-1)*(y1y1-xy1[j]/xx[j]*xy1[j])*(y3y3)^(-1)/(N-1)*(y1y1-y1y3/y3y3*y1y3)))
      cov23[j]<-y2y2/N*xx[j]^(-1)*xy3[j]*(y3y3)^(-1)*sd_gamma_hat*sd_theta_hat/(sqrt((xx[j])^(-1)/(N-1)*(y2y2-xy2[j]/xx[j]*xy2[j])*(y3y3)^(-1)/(N-1)*(y2y2-y2y3/y3y3*y2y3)))          
      var_c[j]<-(solve(v)%*%D%*%matrix(c(var_beta_m_hat[j],cov12[j],cov13[j],cov12[j],var_gamma_hat,cov23[j],cov13[j],cov23[j],var_theta_hat),nrow=3,ncol=3,byrow=F)%*%D%*%solve(v))[1,1]
      z[j]<-beta_c[j]/sqrt(var_c[j])
      pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
    }
  }
  
  final<-data.frame(d,beta_c,z,pval_c)
  
}

#####example
# library(data.table)
# m1<-fread('/restricted/projectnb/sequencing/biqiwang/cond_phenotype/prevAFcov.summary2.commonv',data.table=F)
# m2<-fread('/restricted/projectnb/sequencing/biqiwang/cond_phenotype/fhs_hrc_gwas/geepack/summary2.HRC.r1.1.gwas.2016/summary2/prevmi.summary2.commonv',data.table=F)
# m22<-fread('/restricted/projectnb/sequencing/biqiwang/cond_phenotype/fhs_hrc_gwas/geepack/summary2.HRC.r1.1.gwas.2016/summary2/prevhf.summary2.commonv',data.table=F)
##write.table(m1[1:100,],'/restricted/projectnb/glycemic/peitao/conditional/dy1.twobi',row.names = F,col.names = T,quote = F,sep='\t')
##write.table(m2[1:100,],'/restricted/projectnb/glycemic/peitao/conditional/dy2.twobi',row.names = F,col.names = T,quote = F,sep='\t')
##write.table(m22[1:100,],'/restricted/projectnb/glycemic/peitao/conditional/dy3.twobi',row.names = F,col.names = T,quote = F,sep='\t')



# m3<-fread('/restricted/projectnb/sequencing/biqiwang/cond_phenotype/afprev.cov.2014.csv',data.table=F)
### mm <- data.frame(id=1:500, prevMI = rbinom(500,1,0.1), prevCHF = rbinom(500,1,0.1),prevAF  = rbinom(500,1,0.1) ,sex.x = rbinom(500,1,0.5),dnaage= rnorm(500,mean(m3$dnaage),sd(m3$dnaage)))
####write.table(mm,'/restricted/projectnb/glycemic/peitao/conditional/phe.twobi',row.names = F,col.names = T,quote = F,sep='\t')

# names(m1)<-c("Chr","SNPID","Phys_location","phen","N","iMAF","variMAF","Nd","iMAFd","variMAFd","beta","se","chisq","df","model","remark","pval","effect","noneffect","obs_eaf","ratio","input_snp","iwgadiff","iwgafold","inrefgene","refgenes_60kb_from_SNP","closestrefgene","distancefromclosestrefgene")
# names(m2)<-c("Chr","SNPID","Phys_location","phen","N","iMAF","variMAF","Nd","iMAFd","variMAFd","beta","se","chisq","df","model","remark","pval","effect","noneffect","obs_eaf","ratio","input_snp","iwgadiff","iwgafold","inrefgene","refgenes_60kb_from_SNP","closestrefgene","distancefromclosestrefgene")
# names(m22)<-c("Chr","SNPID","Phys_location","phen","N","iMAF","variMAF","Nd","iMAFd","variMAFd","beta","se","chisq","df","model","remark","pval","effect","noneffect","obs_eaf","ratio","input_snp","iwgadiff","iwgafold","inrefgene","refgenes_60kb_from_SNP","closestrefgene","distancefromclosestrefgene")
# com<-merge(m1,m2,by="SNPID")
# com<-merge(com,m22,by="SNPID")
# com <- com[1:100,]
# r <- nrow(com)
# ####full
# gamma <- get_gamma_full_y2_bi(data =m3,y2 = 'prevAF',y1 = 'prevMI',cor =c('dnaage','sex.x'))
# theta <- get_gamma_full_y2_bi(data =m3,y2 = 'prevAF',y1 = 'prevCHF',cor =c('dnaage','sex.x'))
# r.f <-y1y2_bi(d=com,data=m3,y1='prevMI',y2='prevAF',y3='prevCHF',N2 = 8168,N3 = 8168, Ncase2 = 255, Ncase3 = 106,beta_m_hat = 'beta.x',sd_beta_m_hat = 'se.x',eta_hat = 'beta.y',sd_eta = 'se.y',mu_hat='beta',sd_mu_hat = 'se',maf = 'iMAF.x',N = 8466,Ncase = 319, gamma_hat = gamma[1],sd_gamma_hat =gamma[2],theta_hat = theta[1],sd_theta_hat = theta[2])
# ####subset 
# set.seed(23)
# sub<-m3[sample(1:dim(m3)[1],1000),'id']
# gamma <- get_gamma_subset_y2_bi(data = m3, id ='id',subid= sub,y2 = 'prevAF', y1 = 'prevMI',cor =c('dnaage','sex.x'))
# theta <- get_gamma_subset_y2_bi(data = m3, id ='id',subid= sub,y2 = 'prevAF', y1 = 'prevCHF',cor =c('dnaage','sex.x'))
# 
# r.s <-y1y2_bi(d=com,data=m3,y1='prevMI',y2='prevAF',y3='prevCHF',N2 = 8168,N3 = 8168, Ncase2 = 255, Ncase3 = 106,beta_m_hat = 'beta.x',sd_beta_m_hat = 'se.x',eta_hat = 'beta.y',sd_eta = 'se.y',mu_hat='beta',sd_mu_hat = 'se',maf = 'iMAF.x',N = 8466,Ncase = 319, gamma_hat = gamma[1],sd_gamma_hat =gamma[2],theta_hat = theta[1],sd_theta_hat = theta[2])
# ####literature
# gamma <- c(1.55,0.17)
# theta <- c(3.0,0.2)
# r.s <-y1y2_bi(d=com,data=m3,y1='prevMI',y2='prevAF',y3='prevCHF',N2 = 8168,N3 = 8168, Ncase2 = 255, Ncase3 = 106,beta_m_hat = 'beta.x',sd_beta_m_hat = 'se.x',eta_hat = 'beta.y',sd_eta = 'se.y',mu_hat='beta',sd_mu_hat = 'se',maf = 'iMAF.x',N = 8466,Ncase = 319, gamma_hat = gamma[1],sd_gamma_hat =gamma[2],theta_hat = theta[1],sd_theta_hat = theta[2])


