
##################################################
#Peitao Wu (peitaowu@bu.edu)
#Biqi Wang (wangbiqi@bu.edu)
##################################################


#################function for simulation when y1 and y2 are continuous y1~y2+snp
#######p1 proportion of variation explained by snp in y1~snp
#######p2 proportion of variation explained by snp in y2~snp
#######p21 proportion of variation explained by y2 in y1~y2
#######N sample size
#######r number of replicates
#######maf Minor allele frequency of snp
#######method, either full, subset or random (literature)

two_con<-function(p2,p1,p21,N,r,maf,method)
{

set.seed(23)
x<-matrix(rep(rbinom(N,2,maf),r),N,r)
x<-x-2*maf #centered


tau<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
       dimnames = NULL)
for (j in 1:r)
{tau[,j]<-rnorm(N,0,sqrt(1-p2))}

epsilon<-matrix(data = NA, nrow = N, ncol =r, byrow = FALSE,
       dimnames = NULL)
for (j in 1:r)
{epsilon[,j]<-rnorm(N,0,sqrt(1-p1-p21))}
####
eta<-sqrt(p2/(2*maf*(1-maf)))
beta_m<-sqrt(p1/(2*maf*(1-maf)))
gamma<-sqrt(p21/1) 
####get traits

y2<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
       dimnames = NULL)
for(j in 1:r)
{y2[,j]<-eta*x[,j]+tau[,j]}
     
y1<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
       dimnames = NULL)      
for(j in 1:r)
{y1[,j]<-beta_m*x[,j]+gamma*y2[,j]+epsilon[,j]}
####analysis

beta_m_hat<-c()
var_beta_m_hat<-c()
for(j in 1:r){
mod1<-lm(y1[,j]~x[,j])
beta_m_hat[j]<-summary(mod1)$coefficients[2,1]
var_beta_m_hat[j]<-(summary(mod1)$coefficients[2,2])^2
}

eta_hat<-c()
var_eta_hat<-c()
for(j in 1:r){
mod2<-lm(y2[,j]~x[,j])
eta_hat[j]<-summary(mod2)$coefficients[2,1]
var_eta_hat[j]<-(summary(mod2)$coefficients[2,2])^2
}
se<-c()
beta_hat<-c()
pval<-c()
for(j in 1:r){
mod3<-lm(y1[,j]~x[,j]+y2[,j])
beta_hat[j]<-summary(mod3)$coefficients[2,1]
se[j]<-summary(mod3)$coefficients[2,2]
pval[j]<-summary(mod3)$coefficients[2,4]

}

gamma_hat<-c()
for (j in 1:r){
  mod4<-lm(y1[,j]~y2[,j])
  gamma_hat[j]<-summary(mod4)$coefficients[2,1]
}
g<-mean(gamma_hat)
if (method=="full")
{
gamma_hat<-c()
for (j in 1:r){
mod4<-lm(y1[,j]~y2[,j])
gamma_hat[j]<-summary(mod4)$coefficients[2,1]
}

beta_c<-c()
pval_c<-c()
sd_c<-c()
z<-c()
beta_c2<-c()
y1y1<-c()
y2y2<-c()
sigma_j<-c()
for(j in 1:r)
{#d<-cbind(x[,j],y2[,j])
#v<-t(d)%*%d
y2y2[j]<-(N-1)*N*2*maf*(1-maf)*var_eta_hat[j]+N*2*maf*(1-maf)*(eta_hat[j])^2
v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),y2y2[j]/N),nrow=2,ncol=2,byrow=F)
D<-matrix(c(2*maf*(1-maf),0,0,y2y2[j]/N),nrow=2,ncol=2,byrow=F)
temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
beta_c[j]<-temp[1]
beta_c2[j]<-temp[2]
y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*y2y2[j]*gamma_hat[j])
sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
z[j]<-beta_c[j]/sd_c[j]
pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
}
print(mean(beta_c))
print(mean(sd_c))
print(mean(beta_hat))
print(mean(se))
png(paste0('twocon_',maf,'_full','_beta','.png'))
plot(beta_c,beta_hat)
dev.off()

png(paste0('twocon_',maf,'_full','_p','.png'))
plot(-log(pval_c,base=10),-log(pval,base=10))
abline(0,1)
dev.off()
print(mean(pval<0.05))
print(mean(pval_c<0.05))
}
else if (method=="subset")
{

#####using partial data- estimated \sigma_{y_2}^2
gamma_hat<-c()
for (j in 1:r){
mod4<-lm(y1[1:200,j]~y2[1:200,j])
gamma_hat[j]<-summary(mod4)$coefficients[2,1]
}

beta_c<-c()
pval_c<-c()
sd_c<-c()
z<-c()
beta_c2<-c()
y1y1<-c()
y2y2<-c()
sigma_j<-c()
for(j in 1:r)
{#d<-cbind(x[,j],y2[,j])
#v<-t(d)%*%d
y2y2[j]<-(N-1)*N*2*maf*(1-maf)*var_eta_hat[j]+N*2*maf*(1-maf)*(eta_hat[j])^2
v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),y2y2[j]/N),nrow=2,ncol=2,byrow=F)
D<-matrix(c(2*maf*(1-maf),0,0,y2y2[j]/N),nrow=2,ncol=2,byrow=F)
temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
beta_c[j]<-temp[1]
beta_c2[j]<-temp[2]
y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*y2y2[j]*gamma_hat[j])
sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
z[j]<-beta_c[j]/sd_c[j]
pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
}
print(mean(beta_c))
print(mean(sd_c))
png(paste0('twocon_',maf,'_subset','_beta','.png'))
plot(beta_c,beta_hat)
dev.off()
png(paste0('twocon_',maf,'_subset','_p','.png'))
plot(-log(pval_c,base=10),-log(pval,base=10))
abline(0,1)
dev.off()
print(mean(pval<0.05))
print(mean(pval_c<0.05))
}


else if (method=="random")

{


####random guess



beta_c<-c()
pval_c<-c()
sd_c<-c()
z<-c()
beta_c2<-c()
y1y1<-c()
y2y2<-c()
sigma_j<-c()
for(j in 1:r)
{#d<-cbind(x[,j],y2[,j])
#v<-t(d)%*%d
gamma_hat<-runif(1,g*0.8,g*1.2)
y2y2[j]<-(N-1)*N*2*maf*(1-maf)*var_eta_hat[j]+N*2*maf*(1-maf)*(eta_hat[j])^2
v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),y2y2[j]/N),nrow=2,ncol=2,byrow=F)
D<-matrix(c(2*maf*(1-maf),0,0,y2y2[j]/N),nrow=2,ncol=2,byrow=F)
temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat)	
beta_c[j]<-temp[1]
beta_c2[j]<-temp[2]
y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*y2y2[j]*gamma_hat)
sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
z[j]<-beta_c[j]/sd_c[j]
pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
}
print(mean(beta_c))
print(mean(sd_c))
png(paste0('twocon_',maf,'_random','_beta','.png'))
plot(beta_c,beta_hat)
dev.off()
png(paste0('twocon_',maf,'_random','_p','.png'))
plot(-log(pval_c,base=10),-log(pval,base=10))
abline(0,1)
dev.off()
print(mean(pval<0.05))
print(mean(pval_c<0.05))
}

}
setwd("~/Google Drive/conditional analysis/newsimulation_10")
two_con(p2=0.04,p1=0.02,p21=0.2,N=1000,r=1000,maf=0.10,method='full')
two_con(p2=0.04,p1=0.02,p21=0.2,N=1000,r=1000,maf=0.10,method='subset')
two_con(p2=0.04,p1=0.02,p21=0.2,N=1000,r=1000,maf=0.10,method='random')
setwd("~/Google Drive/conditional analysis/newsimulation_10/0.02")
two_con(p2=0.04,p1=0.02,p21=0.02,N=1000,r=1000,maf=0.10,method='full')
two_con(p2=0.04,p1=0.02,p21=0.02,N=1000,r=1000,maf=0.10,method='subset')
two_con(p2=0.04,p1=0.02,p21=0.02,N=1000,r=1000,maf=0.10,method='random')

two_con(p2=0.04,p1=0.02,p21=0.2,N=1000,r=1000,maf=0.25,method='full')
two_con(p2=0.04,p1=0.02,p21=0.2,N=1000,r=1000,maf=0.02,method='subset')
two_con(p2=0.04,p1=0.02,p21=0.2,N=1000,r=1000,maf=0.02,method='random')


#######type 1 error

###snp unasso trait and cov
setwd("~/Google Drive/conditional analysis/t1e")
two_con(p2=0.00,p1=0.00,p21=0.2,N=1000,r=1000,maf=0.25,method='full')
two_con(p2=0.00,p1=0.00,p21=0.2,N=1000,r=1000,maf=0.25,method='subset')
two_con(p2=0.00,p1=0.00,p21=0.2,N=1000,r=1000,maf=0.25,method='random')


two_con(p2=0.00,p1=0.00,p21=0.2,N=1000,r=1000,maf=0.10,method='full')
two_con(p2=0.00,p1=0.00,p21=0.2,N=1000,r=1000,maf=0.10,method='subset')
two_con(p2=0.00,p1=0.00,p21=0.2,N=1000,r=1000,maf=0.10,method='random')


two_con(p2=0.00,p1=0.00,p21=0.2,N=1000,r=1000,maf=0.05,method='full')
two_con(p2=0.00,p1=0.00,p21=0.2,N=1000,r=1000,maf=0.05,method='subset')
two_con(p2=0.00,p1=0.00,p21=0.2,N=1000,r=1000,maf=0.05,method='random')

two_con(p2=0.00,p1=0.00,p21=0.2,N=1000,r=1000,maf=0.02,method='full')
two_con(p2=0.00,p1=0.00,p21=0.2,N=1000,r=1000,maf=0.02,method='subset')
two_con(p2=0.00,p1=0.00,p21=0.2,N=1000,r=1000,maf=0.02,method='random')



###snp with cov snp unasso trait
two_con<-function(p2,p1,p21,N,n0,alpha,r,maf,method)
{
  
  set.seed(23)
  x<-matrix(rep(rbinom(N,2,maf),r),N,r)
  x<-x-2*maf #centered
  
  
  tau<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
              dimnames = NULL)
  for (j in 1:r)
  {tau[,j]<-rnorm(N,0,sqrt(1-p2))}
  
  epsilon<-matrix(data = NA, nrow = N, ncol =r, byrow = FALSE,
                  dimnames = NULL)
  for (j in 1:r)
  {epsilon[,j]<-rnorm(N,0,sqrt(1-p1-p21))}
  ####
  eta<-sqrt(p2/(2*maf*(1-maf)))
  beta_m<-sqrt(p1/(2*maf*(1-maf)))
  gamma<-sqrt(p21/1) 
  ####get traits
  
  y2<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
             dimnames = NULL)
  for(j in 1:r)
  {y2[,j]<-eta*x[,j]+tau[,j]}
  
  y1<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
             dimnames = NULL)      
  for(j in 1:r)
  {y1[,j]<-beta_m*x[,j]+gamma*y2[,j]+epsilon[,j]}
  ####analysis
  
  beta_m_hat<-c()
  var_beta_m_hat<-c()
  for(j in 1:r){
    mod1<-lm(y1[,j]~x[,j])
    beta_m_hat[j]<-summary(mod1)$coefficients[2,1]
    var_beta_m_hat[j]<-(summary(mod1)$coefficients[2,2])^2
  }
  
  eta_hat<-c()
  var_eta_hat<-c()
  for(j in 1:r){
    mod2<-lm(y2[,j]~x[,j])
    eta_hat[j]<-summary(mod2)$coefficients[2,1]
    var_eta_hat[j]<-(summary(mod2)$coefficients[2,2])^2
  }
  se<-c()
  beta_hat<-c()
  pval<-c()
  for(j in 1:r){
    mod3<-lm(y1[,j]~x[,j]+y2[,j])
    beta_hat[j]<-summary(mod3)$coefficients[2,1]
    se[j]<-summary(mod3)$coefficients[2,2]
    pval[j]<-summary(mod3)$coefficients[2,4]
    
  }
  
  gamma_hat<-c()
  for (j in 1:r){
    mod4<-lm(y1[,j]~y2[,j])
    gamma_hat[j]<-summary(mod4)$coefficients[2,1]
  }
  g<-mean(gamma_hat)
  if (method=="full")
  {
    gamma_hat<-c()
    for (j in 1:r){
      mod4<-lm(y1[,j]~y2[,j])
      gamma_hat[j]<-summary(mod4)$coefficients[2,1]
    }
    
    beta_c<-c()
    pval_c<-c()
    sd_c<-c()
    z<-c()
    beta_c2<-c()
    y1y1<-c()
    y2y2<-c()
    sigma_j<-c()
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      y2y2[j]<-(N-1)*N*2*maf*(1-maf)*var_eta_hat[j]+N*2*maf*(1-maf)*(eta_hat[j])^2
      v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),y2y2[j]/N),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,y2y2[j]/N),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
      beta_c[j]<-temp[1]
      beta_c2[j]<-temp[2]
      y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
      sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*y2y2[j]*gamma_hat[j])
      sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
      z[j]<-beta_c[j]/sd_c[j]
      pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
    }
    print(mean(beta_c))
    print(mean(sd_c))
    print(mean(beta_hat))
    print(mean(se))
    png(paste0('twocon_',maf,'_full','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    
    png(paste0('twocon_',maf,'_full','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    print(mean(pval<0.05))
    print(mean(pval_c<0.05))
  }
  else if (method=="subset")
  {
    
    #####using partial data- estimated \sigma_{y_2}^2
    gamma_hat<-c()
    for (j in 1:r){
      mod4<-lm(y1[1:n0,j]~y2[1:n0,j])
      gamma_hat[j]<-summary(mod4)$coefficients[2,1]
    }
    
    beta_c<-c()
    pval_c<-c()
    sd_c<-c()
    z<-c()
    beta_c2<-c()
    y1y1<-c()
    y2y2<-c()
    sigma_j<-c()
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      y2y2[j]<-(N-1)*N*2*maf*(1-maf)*var_eta_hat[j]+N*2*maf*(1-maf)*(eta_hat[j])^2
      v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),y2y2[j]/N),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,y2y2[j]/N),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
      beta_c[j]<-temp[1]
      beta_c2[j]<-temp[2]
      y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
      sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*y2y2[j]*gamma_hat[j])
      sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
      z[j]<-beta_c[j]/sd_c[j]
      pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
    }
    print(mean(beta_c))
    print(mean(sd_c))
    png(paste0('twocon_',maf,'_subset','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    png(paste0('twocon_',maf,'_subset','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    print(mean(pval<0.05))
    print(mean(pval_c<0.05))
  }
  
  
  else if (method=="random")
    
  {
    
    
    ####random guess
    
    
    
    beta_c<-c()
    pval_c<-c()
    sd_c<-c()
    z<-c()
    beta_c2<-c()
    y1y1<-c()
    y2y2<-c()
    sigma_j<-c()
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      gamma_hat<-runif(1,g*(1-alpha),g*(1+alpha))
      y2y2[j]<-(N-1)*N*2*maf*(1-maf)*var_eta_hat[j]+N*2*maf*(1-maf)*(eta_hat[j])^2
      v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),y2y2[j]/N),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,y2y2[j]/N),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat)	
      beta_c[j]<-temp[1]
      beta_c2[j]<-temp[2]
      y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
      sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*y2y2[j]*gamma_hat)
      sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
      z[j]<-beta_c[j]/sd_c[j]
      pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
    }
    print(mean(beta_c))
    print(mean(sd_c))
    png(paste0('twocon_',maf,'_random','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    png(paste0('twocon_',maf,'_random','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    print(mean(pval<0.05))
    print(mean(pval_c<0.05))
  }
  
}
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.25,method='full')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=500,alpha=0.1,r=1000,maf=0.25,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.25,method='random')


two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.10,method='full')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.10,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.10,method='random')


two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.05,method='full')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.05,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.05,method='random')

two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.02,method='full')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.02,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.02,method='random')







#######




two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=300,alpha=0.1,r=1000,maf=0.25,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.25,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=500,alpha=0.1,r=1000,maf=0.25,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=600,alpha=0.1,r=1000,maf=0.25,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=700,alpha=0.1,r=1000,maf=0.25,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=800,alpha=0.1,r=1000,maf=0.25,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=900,alpha=0.1,r=1000,maf=0.25,method='subset')


two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=300,alpha=0.1,r=1000,maf=0.1,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.1,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=500,alpha=0.1,r=1000,maf=0.1,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=600,alpha=0.1,r=1000,maf=0.1,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=700,alpha=0.1,r=1000,maf=0.1,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=800,alpha=0.1,r=1000,maf=0.1,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=900,alpha=0.1,r=1000,maf=0.1,method='subset')

two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=300,alpha=0.1,r=1000,maf=0.05,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.05,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=500,alpha=0.1,r=1000,maf=0.05,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=600,alpha=0.1,r=1000,maf=0.05,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=700,alpha=0.1,r=1000,maf=0.05,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=800,alpha=0.1,r=1000,maf=0.05,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=900,alpha=0.1,r=1000,maf=0.05,method='subset')


two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=300,alpha=0.1,r=1000,maf=0.02,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.02,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=500,alpha=0.1,r=1000,maf=0.02,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=600,alpha=0.1,r=1000,maf=0.02,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=700,alpha=0.1,r=1000,maf=0.02,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=800,alpha=0.1,r=1000,maf=0.02,method='subset')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=900,alpha=0.1,r=1000,maf=0.02,method='subset')









two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=300,alpha=0.15,r=1000,maf=0.25,method='random')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.25,method='random')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=500,alpha=0.05,r=1000,maf=0.25,method='random')

two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=300,alpha=0.15,r=1000,maf=0.1,method='random')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.1,method='random')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=500,alpha=0.05,r=1000,maf=0.1,method='random')


two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=300,alpha=0.15,r=1000,maf=0.05,method='random')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.05,method='random')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=500,alpha=0.05,r=1000,maf=0.05,method='random')



two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=300,alpha=0.15,r=1000,maf=0.02,method='random')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=400,alpha=0.1,r=1000,maf=0.02,method='random')
two_con(p2=0.04,p1=0.00,p21=0.2,N=1000,n0=500,alpha=0.05,r=1000,maf=0.02,method='random')


###############power

two_con(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,maf=0.25,method='full')
two_con(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,maf=0.25,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,maf=0.25,method='random')


two_con(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,maf=0.25,method='full')
two_con(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,maf=0.25,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,maf=0.25,method='random')


two_con(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,maf=0.25,method='full')
two_con(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,maf=0.25,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,maf=0.25,method='random')

two_con(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,maf=0.25,method='full')
two_con(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,maf=0.25,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,maf=0.25,method='random')


two_con(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,maf=0.1,method='full')
two_con(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,maf=0.1,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,maf=0.1,method='random')


two_con(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,maf=0.1,method='full')
two_con(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,maf=0.1,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,maf=0.1,method='random')


two_con(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,maf=0.1,method='full')
two_con(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,maf=0.1,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,maf=0.1,method='random')

two_con(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,maf=0.1,method='full')
two_con(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,maf=0.1,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,maf=0.1,method='random')


two_con(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,maf=0.05,method='full')
two_con(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,maf=0.05,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,maf=0.05,method='random')


two_con(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,maf=0.05,method='full')
two_con(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,maf=0.05,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,maf=0.05,method='random')


two_con(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,maf=0.05,method='full')
two_con(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,maf=0.05,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,maf=0.05,method='random')

two_con(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,maf=0.05,method='full')
two_con(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,maf=0.05,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,maf=0.05,method='random')


two_con(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,maf=0.02,method='full')
two_con(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,maf=0.02,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,maf=0.02,method='random')


two_con(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,maf=0.02,method='full')
two_con(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,maf=0.02,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,maf=0.02,method='random')


two_con(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,maf=0.02,method='full')
two_con(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,maf=0.02,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,maf=0.02,method='random')

two_con(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,maf=0.02,method='full')
two_con(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,maf=0.02,method='subset')
two_con(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,maf=0.02,method='random')
