
##################################################
#Peitao Wu (peitaowu@bu.edu)
#Biqi Wang (wangbiqi@bu.edu)
##################################################

################binary tarits
#################function for simulation when y2 is continuous and y1 is binary y1~y2+snp
#######p2 proportion of variation explained by snp in y2~snp
#######N sample size
#######r number of replicates
#######maf Minor allele frequency of snp
#######method, either full, subset or random (literature)
#######f0 P(Y1=1|Snp=0,y2)
#######f1 P(Y1=1|Snp=1,y2)
#######f2 P(Y1=1|Snp=2,y2)

y1binary<-function(p2,N,r,f0,f1,f2,maf,method){
set.seed(23)
x<-matrix(rep(rbinom(N,2,maf),r),N,r)
#x<-x-0.5 #centered


tau<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
       dimnames = NULL)
for (j in 1:r)
{tau[,j]<-rnorm(N,0,sqrt(1-p2))}


####
eta<-sqrt(p2/(2*maf*(1-maf)))

####get traits

y2<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
       dimnames = NULL)
for(j in 1:r)
{y2[,j]<-eta*x[,j]+tau[,j]}
     
y1<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
       dimnames = NULL) 

for (j in 1:r){
for (i in 1:N){
	y1[i,j]<-ifelse(x[i,j]==0,ifelse(runif(1,0,1)<=f0&y2[i,j]>quantile(y2[,j],0.2),1,0),ifelse(x[i,j]==1,ifelse(runif(1,0,1)<=f1&y2[i,j]>quantile(y2[,j],0.2),1,0),ifelse(runif(1,0,1)<=f2&y2[i,j]>quantile(y2[,j],0.2),1,0)))
}
}
	
	

beta_m_hat<-c()
sd_beta_m_hat<-c()
for(j in 1:r){
mod1<-glm(y1[,j]~x[,j],family=binomial)
beta_m_hat[j]<-summary(mod1)$coefficients[2,1]
sd_beta_m_hat[j]<-summary(mod1)$coefficients[2,2]
}
var_beta_m_hat<-sd_beta_m_hat^2
eta_hat<-c()
sd_eta<-c()
for(j in 1:r){
mod2<-lm(y2[,j]~x[,j])
eta_hat[j]<-summary(mod2)$coefficients[2,1]
sd_eta[j]<-summary(mod2)$coefficients[2,2]
}

se<-c()
beta_hat<-c()
pval<-c()
for(j in 1:r){
mod3<-glm(y1[,j]~x[,j]+y2[,j],family=binomial)
beta_hat[j]<-summary(mod3)$coefficients[2,1]
beta_hat[j]<-summary(mod3)$coefficients[2,1]
se[j]<-summary(mod3)$coefficients[2,2]
pval[j]<-summary(mod3)$coefficients[2,4]

}

gamma_hat<-c()
sd_gamma_hat<-c()
for (j in 1:r){
mod4<-glm(y1[,j]~y2[,j],family=binomial)
gamma_hat[j]<-summary(mod4)$coefficients[2,1]
sd_gamma_hat[j]<-summary(mod4)$coefficients[2,2]
}

g<-mean(gamma_hat)
g_s<-mean(sd_gamma_hat)

xx<-2*maf*(1-maf)*(N)
y2y2<-(N-1)*xx*sd_eta^2+xx*(eta_hat)^2

p_y1<-c()
for(j in 1:r){
	p_y1[j]<-sum(y1[,j])/1000
}
y1y1<-N*p_y1*(1-p_y1)
xy2<-xx*eta_hat



######get xy1
p0<-c()
p1<-c()
s<-function(a,b,c,p)
{
  p1[1]<-(-b+p-a*p-a*c+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
  p1[2]<-(-b+p-a*p-a*c-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
  p0[1]<-(-a*p+p-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
  p0[2]<-(-a*p+p+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
  return(c(p0,p1))
}
u<-c()
for (j in 1:r){
temp<-s(exp(beta_m_hat[j]),(N-sum(y1[,j]))/N,sum(y1[,j])/1000,maf)
u<-rbind(u,temp)
}
u<-u[,c(1,3)]
a<-c()
b<-c()
c<-c()
d<-c()
e<-c()
f<-c()
for(j in 1:r)
{
  a[j]<-(1-u[j,1])^2*(N-sum(y1[,j]))
  c[j]<-2*(1-u[j,1])*u[j,1]*(N-sum(y1[,j]))
  e[j]<-u[j,1]^2*(N-sum(y1[,j]))
  
  b[j]<-(1-u[j,2])^2*(sum(y1[,j]))
  d[j]<-2*(1-u[j,2])*u[j,2]*(sum(y1[,j]))
  f[j]<-u[j,2]^2*(sum(y1[,j]))
}
est<-cbind(a,c,e,b,d,f)
est_cov<-c()
true_cov<-c()

for(j in 1:r)
{
  est_cov[j]<-1/N*(est[j,1]*(2*maf)*(mean(y1[,j]))+est[j,2]*(1-2*maf)*(0-mean(y1[,j]))+est[j,3]*(2-2*maf)*(0-mean(y1[,j]))+est[j,4]*(0-2*maf)*(1-mean(y1[,j]))
                      +est[j,5]*(1-2*maf)*(1-mean(y1[,j]))+est[j,6]*(2-2*maf)*(1-mean(y1[,j])))
  
  true_cov[j]<-cov(x[,j],y1[,j])
}

xy1<-est_cov*N
y1y2<-c()
for(j in 1:r)
{
	y1y2[j]<-cov(y1[j,],y2[,j])*N
}


if (method=='full'){

var_beta_m_hat<-sd_beta_m_hat^2
var_gamma_hat<-sd_gamma_hat^2
beta_c<-c()

pval_c<-c()
var_c<-c()
sd_c<-c()
z<-c()
for(j in 1:r)
{#d<-cbind(x[,j],y2[,j])
#v<-t(d)%*%d
v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),1),nrow=2,ncol=2,byrow=F)
D<-matrix(c(2*maf*(1-maf),0,0,1),nrow=2,ncol=2,byrow=F)
temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
beta_c[j]<-temp[1]
var_c[j]<-(solve(v)%*%D%*%matrix(c(var_beta_m_hat[j],y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat[j]/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat[j]/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),var_gamma_hat[j]),nrow=2,ncol=2,byrow=F)%*%D%*%solve(v))[1,1]
sd_c[j]<-sqrt(var_c[j])
z[j]<-beta_c[j]/sqrt(var_c[j])
pval_c[j]<-2*pnorm(-abs(z[j]))

}

print(mean(beta_c))
print(mean(sd_c))
print(mean(beta_hat))
print(mean(se))

png(paste0('y1bi_',maf,'_full','_beta','.png'))
plot(beta_c,beta_hat)
dev.off()

png(paste0('y1bi_',maf,'_full','_p','.png'))
plot(-log(pval_c,base=10),-log(pval,base=10))
abline(0,1)
dev.off()

}
else if(method=='subset')
{
	gamma_hat<-c()
sd_gamma_hat<-c()
for (j in 1:r){
mod4<-glm(y1[1:200,j]~y2[1:200,j],family=binomial)
gamma_hat[j]<-summary(mod4)$coefficients[2,1]
sd_gamma_hat[j]<-summary(mod4)$coefficients[2,2]
}

var_beta_m_hat<-sd_beta_m_hat^2
var_gamma_hat<-sd_gamma_hat^2
beta_c<-c()

pval_c<-c()
var_c<-c()
sd_c<-c()
z<-c()
for(j in 1:r)
{#d<-cbind(x[,j],y2[,j])
#v<-t(d)%*%d
v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),1),nrow=2,ncol=2,byrow=F)
D<-matrix(c(2*maf*(1-maf),0,0,1),nrow=2,ncol=2,byrow=F)
temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
beta_c[j]<-temp[1]
var_c[j]<-(solve(v)%*%D%*%matrix(c(var_beta_m_hat[j],y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat[j]/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat[j]/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),var_gamma_hat[j]),nrow=2,ncol=2,byrow=F)%*%D%*%solve(v))[1,1]
sd_c[j]<-sqrt(var_c[j])
z[j]<-beta_c[j]/sqrt(var_c[j])
pval_c[j]<-2*pnorm(-abs(z[j]))

}

print(mean(beta_c))
print(mean(sd_c))
png(paste0('y1bi_',maf,'_subset','_beta','.png'))
plot(beta_c,beta_hat)
dev.off()
png(paste0('y1bi_',maf,'_subset','_p','.png'))
plot(-log(pval_c,base=10),-log(pval,base=10))
abline(0,1)
dev.off()
}

else if(method=="random")
{
	beta_c<-c()

pval_c<-c()
var_c<-c()
sd_c<-c()
z<-c()
for(j in 1:r)
{#d<-cbind(x[,j],y2[,j])
#v<-t(d)%*%d
sd_gamma_hat<-runif(1,g_s*0.8,g_s*1.2)
var_gamma_hat<-sd_gamma_hat^2
v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),y2y2[j]),nrow=2,ncol=2,byrow=F)
D<-matrix(c(2*maf*(1-maf),0,0,y2y2[j]),nrow=2,ncol=2,byrow=F)
temp<-solve(v)%*%D%*%c(beta_m_hat[j],runif(1,g*0.8,g*1.2))	
beta_c[j]<-temp[1]
var_c[j]<-(solve(v)%*%D%*%matrix(c(var_beta_m_hat[j],y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),var_gamma_hat),nrow=2,ncol=2,byrow=F)%*%D%*%solve(v))[1,1]
z[j]<-beta_c[j]/sqrt(var_c[j])
sd_c[j]<-sqrt(var_c[j])
pval_c[j]<-2*pnorm(-abs(z[j]))
}

print(mean(beta_c))
print(mean(sd_c))
png(paste0('y1bi_',maf,'_random','_beta','.png'))
plot(beta_c,beta_hat)
dev.off()
png(paste0('y1bi_',maf,'_random','_p','.png'))
plot(-log(pval_c,base=10),-log(pval,base=10))
abline(0,1)
dev.off()
}


}
setwd("~/Google Drive/conditional analysis/newsimulation_10")
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='full')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='subset')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='random')



y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='full')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='subset')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='random')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='full')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='subset')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='random')


#########type 1 error

y1binary<-function(p2,N,r,f0,f1,f2,maf,method){
  set.seed(23)
  x<-matrix(rep(rbinom(N,2,maf),r),N,r)
  #x<-x-0.5 #centered
  
  
  tau<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
              dimnames = NULL)
  for (j in 1:r)
  {tau[,j]<-rnorm(N,0,sqrt(1-p2))}
  
  
  ####
  eta<-sqrt(p2/(2*maf*(1-maf)))
  #eta<-0
  
  ####get traits
  
  y2<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
             dimnames = NULL)
  for(j in 1:r)
  {y2[,j]<-eta*x[,j]+tau[,j]}
  
  y1<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
             dimnames = NULL) 
  
  for (j in 1:r){
    for (i in 1:N){
      y1[i,j]<-1/(1+exp(-1-0.413*y2[i,j]-rnorm(1,0,sqrt(0.8))))
    }
  }
  
  
 t <- (y1>0.869)*1
  y1<-t
  
  # for (j in 1:r){
  #   for (i in 1:N){
  #     y1[i,j]<-ifelse(runif(1,0,1)<=0.7&y2[i,j]>quantile(y2[,j],0.7),1,0)
  #     }
  # }
  # 
  
  
  beta_m_hat<-c()
  sd_beta_m_hat<-c()
  for(j in 1:r){
    mod1<-glm(y1[,j]~x[,j],family=binomial)
    beta_m_hat[j]<-summary(mod1)$coefficients[2,1]
    sd_beta_m_hat[j]<-summary(mod1)$coefficients[2,2]
  }
  var_beta_m_hat<-sd_beta_m_hat^2
  eta_hat<-c()
  sd_eta<-c()
  for(j in 1:r){
    mod2<-lm(y2[,j]~x[,j])
    eta_hat[j]<-summary(mod2)$coefficients[2,1]
    sd_eta[j]<-summary(mod2)$coefficients[2,2]
  }
  
  se<-c()
  beta_hat<-c()
  pval<-c()
  for(j in 1:r){
    mod3<-glm(y1[,j]~x[,j]+y2[,j],family=binomial)
    beta_hat[j]<-summary(mod3)$coefficients[2,1]
    beta_hat[j]<-summary(mod3)$coefficients[2,1]
    se[j]<-summary(mod3)$coefficients[2,2]
    pval[j]<-summary(mod3)$coefficients[2,4]
    
  }
  
  gamma_hat<-c()
  sd_gamma_hat<-c()
  for (j in 1:r){
    mod4<-glm(y1[,j]~y2[,j],family=binomial)
    gamma_hat[j]<-summary(mod4)$coefficients[2,1]
    sd_gamma_hat[j]<-summary(mod4)$coefficients[2,2]
  }
  
  g<-mean(gamma_hat)
  g_s<-mean(sd_gamma_hat)
  
  xx<-2*maf*(1-maf)*(N)
  y2y2<-(N-1)*xx*sd_eta^2+xx*(eta_hat)^2
  
  p_y1<-c()
  for(j in 1:r){
    p_y1[j]<-sum(y1[,j])/1000
  }
  y1y1<-N*p_y1*(1-p_y1)
  xy2<-xx*eta_hat
  
  
  
  ######get xy1
  p0<-c()
  p1<-c()
  s<-function(a,b,c,p)
  {
    p1[1]<-(-b+p-a*p-a*c+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
    p1[2]<-(-b+p-a*p-a*c-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
    p0[1]<-(-a*p+p-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
    p0[2]<-(-a*p+p+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
    return(c(p0,p1))
  }
  u<-c()
  for (j in 1:r){
    temp<-s(exp(beta_m_hat[j]),(N-sum(y1[,j]))/N,sum(y1[,j])/1000,maf)
    u<-rbind(u,temp)
  }
  u<-u[,c(1,3)]
  a<-c()
  b<-c()
  c<-c()
  d<-c()
  e<-c()
  f<-c()
  for(j in 1:r)
  {
    a[j]<-(1-u[j,1])^2*(N-sum(y1[,j]))
    c[j]<-2*(1-u[j,1])*u[j,1]*(N-sum(y1[,j]))
    e[j]<-u[j,1]^2*(N-sum(y1[,j]))
    
    b[j]<-(1-u[j,2])^2*(sum(y1[,j]))
    d[j]<-2*(1-u[j,2])*u[j,2]*(sum(y1[,j]))
    f[j]<-u[j,2]^2*(sum(y1[,j]))
  }
  est<-cbind(a,c,e,b,d,f)
  est_cov<-c()
  true_cov<-c()
  
  for(j in 1:r)
  {
    est_cov[j]<-1/N*(est[j,1]*(2*maf)*(mean(y1[,j]))+est[j,2]*(1-2*maf)*(0-mean(y1[,j]))+est[j,3]*(2-2*maf)*(0-mean(y1[,j]))+est[j,4]*(0-2*maf)*(1-mean(y1[,j]))
                     +est[j,5]*(1-2*maf)*(1-mean(y1[,j]))+est[j,6]*(2-2*maf)*(1-mean(y1[,j])))
    
    true_cov[j]<-cov(x[,j],y1[,j])
  }
  
  xy1<-est_cov*N
  y1y2<-c()
  for(j in 1:r)
  {
    y1y2[j]<-cov(y1[j,],y2[,j])*N
  }
  
  
  if (method=='full'){
    
    var_beta_m_hat<-sd_beta_m_hat^2
    var_gamma_hat<-sd_gamma_hat^2
    beta_c<-c()
    
    pval_c<-c()
    var_c<-c()
    sd_c<-c()
    z<-c()
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),1),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,1),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
      beta_c[j]<-temp[1]
      var_c[j]<-(solve(v)%*%D%*%matrix(c(var_beta_m_hat[j],y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat[j]/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat[j]/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),var_gamma_hat[j]),nrow=2,ncol=2,byrow=F)%*%D%*%solve(v))[1,1]
      sd_c[j]<-sqrt(var_c[j])
      z[j]<-beta_c[j]/sqrt(var_c[j])
      pval_c[j]<-2*pnorm(-abs(z[j]))
      
    }
    
    print(mean(beta_c),na.rm=T)
    print(mean(sd_c),na.rm=T)
    print(mean(beta_hat),na.rm=T)
    print(mean(se),na.rm=T)
    
    png(paste0('y1bi_',maf,'_full','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    
    png(paste0('y1bi_',maf,'_full','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    print(mean(pval<0.05),na.rm=T)
    print(mean(pval_c<0.05),na.rm=T)
  }
  else if(method=='subset')
  {
    gamma_hat<-c()
    sd_gamma_hat<-c()
    for (j in 1:r){
      mod4<-glm(y1[1:200,j]~y2[1:200,j],family=binomial)
      gamma_hat[j]<-summary(mod4)$coefficients[2,1]
      sd_gamma_hat[j]<-summary(mod4)$coefficients[2,2]
    }
    
    var_beta_m_hat<-sd_beta_m_hat^2
    var_gamma_hat<-sd_gamma_hat^2
    beta_c<-c()
    
    pval_c<-c()
    var_c<-c()
    sd_c<-c()
    z<-c()
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),1),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,1),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
      beta_c[j]<-temp[1]
      var_c[j]<-(solve(v)%*%D%*%matrix(c(var_beta_m_hat[j],y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat[j]/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat[j]/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),var_gamma_hat[j]),nrow=2,ncol=2,byrow=F)%*%D%*%solve(v))[1,1]
      sd_c[j]<-sqrt(var_c[j])
      z[j]<-beta_c[j]/sqrt(var_c[j])
      pval_c[j]<-2*pnorm(-abs(z[j]))
      
    }
    
    print(mean(beta_c),na.rm=T)
    print(mean(sd_c),na.rm=T)
    png(paste0('y1bi_',maf,'_subset','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    png(paste0('y1bi_',maf,'_subset','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    print(mean(pval<0.05),na.rm=T)
    print(mean(pval_c<0.05),na.rm=T)
  }
  
  else if(method=="random")
  {
    beta_c<-c()
    
    pval_c<-c()
    var_c<-c()
    sd_c<-c()
    z<-c()
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      sd_gamma_hat<-runif(1,g_s*0.8,g_s*1.2)
      var_gamma_hat<-sd_gamma_hat^2
      v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),y2y2[j]),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,y2y2[j]),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],runif(1,g*0.8,g*1.2))	
      beta_c[j]<-temp[1]
      var_c[j]<-(solve(v)%*%D%*%matrix(c(var_beta_m_hat[j],y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),var_gamma_hat),nrow=2,ncol=2,byrow=F)%*%D%*%solve(v))[1,1]
      z[j]<-beta_c[j]/sqrt(var_c[j])
      sd_c[j]<-sqrt(var_c[j])
      pval_c[j]<-2*pnorm(-abs(z[j]))
    }
    
    print(mean(beta_c),na.rm=T)
    print(mean(sd_c),na.rm=T)
    png(paste0('y1bi_',maf,'_random','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    png(paste0('y1bi_',maf,'_random','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    print(mean(pval<0.05),na.rm=T)
    print(mean(pval_c<0.05),na.rm=T)
  }
  
  
}

y1binary(0.0,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='full')
y1binary(0.0,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='subset')
y1binary(0.0,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='random')

y1binary(0.0,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='full')
y1binary(0.0,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='subset')
y1binary(0.0,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='random')



y1binary(0.0,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='full')
y1binary(0.0,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='subset')
y1binary(0.0,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='random')

y1binary(0.0,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.021,method='full')
y1binary(0.0,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.021,method='subset')
y1binary(0.0,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.021,method='random')

y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='full')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='subset')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='random')

y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='full')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='subset')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='random')



y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='full')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='subset')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='random')

y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='full')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='subset')
y1binary(0.04,1000,1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='random')



#####power


y1binary<-function(p2,p1,p21,N,r,f0,f1,f2,maf,method){
  set.seed(23)
  x<-matrix(rep(rbinom(N,2,maf),r),N,r)
  #x<-x-0.5 #centered
  
  
  tau<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
              dimnames = NULL)
  for (j in 1:r)
  {tau[,j]<-rnorm(N,0,sqrt(1-p2))}
  eta<-sqrt(p2/(2*maf*(1-maf)))

  y2<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
             dimnames = NULL)
  for(j in 1:r)
  {y2[,j]<-eta*x[,j]+tau[,j]}
  ####
  #eta<-sqrt(p2/(2*maf*(1-maf)))
  #eta<-0
  
  ####get traits
  

  
  
  beta_m<-sqrt(p1*0.2*0.8/(2*maf*(1-maf)))
  gamma<-sqrt(p21*0.2*0.8)
  y1<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
             dimnames = NULL) 
  
  for (j in 1:r){
    for (i in 1:N){
      y1[i,j]<-1/(1+exp(-beta_m*x[i,j]-gamma*y2[i,j]-rnorm(1,0,sqrt(1-p1-p21))))
    }
  }
  
  # for (t in seq(0.5,0.999),0.01){
  # tt <- (y1>t)*1
  # if (abs(mean(tt)-0.2)<1e-2){break()}
  #   print(t)
  # }
  
  for (t in seq(0.5,0.999,0.001)){
    tt <- (y1>t)*1
    if (abs(mean(tt)-0.2)<1e-2) break()
    }
  
  
  y1<-(y1>t)*1
  
  # for (j in 1:r){
  #   for (i in 1:N){
  #     y1[i,j]<-ifelse(runif(1,0,1)<=0.7&y2[i,j]>quantile(y2[,j],0.7),1,0)
  #     }
  # }
  # 
  
  
  beta_m_hat<-c()
  sd_beta_m_hat<-c()
  for(j in 1:r){
    mod1<-glm(y1[,j]~x[,j],family=binomial)
    beta_m_hat[j]<-summary(mod1)$coefficients[2,1]
    sd_beta_m_hat[j]<-summary(mod1)$coefficients[2,2]
  }
  var_beta_m_hat<-sd_beta_m_hat^2
  eta_hat<-c()
  sd_eta<-c()
  for(j in 1:r){
    mod2<-lm(y2[,j]~x[,j])
    eta_hat[j]<-summary(mod2)$coefficients[2,1]
    sd_eta[j]<-summary(mod2)$coefficients[2,2]
  }
  
  se<-c()
  beta_hat<-c()
  pval<-c()
  for(j in 1:r){
    mod3<-glm(y1[,j]~x[,j]+y2[,j],family=binomial)
    beta_hat[j]<-summary(mod3)$coefficients[2,1]
    beta_hat[j]<-summary(mod3)$coefficients[2,1]
    se[j]<-summary(mod3)$coefficients[2,2]
    pval[j]<-summary(mod3)$coefficients[2,4]
    
  }
  
  gamma_hat<-c()
  sd_gamma_hat<-c()
  for (j in 1:r){
    mod4<-glm(y1[,j]~y2[,j],family=binomial)
    gamma_hat[j]<-summary(mod4)$coefficients[2,1]
    sd_gamma_hat[j]<-summary(mod4)$coefficients[2,2]
  }
  
  g<-mean(gamma_hat)
  g_s<-mean(sd_gamma_hat)
  
  xx<-2*maf*(1-maf)*(N)
  y2y2<-(N-1)*xx*sd_eta^2+xx*(eta_hat)^2
  
  p_y1<-c()
  for(j in 1:r){
    p_y1[j]<-sum(y1[,j])/1000
  }
  y1y1<-N*p_y1*(1-p_y1)
  xy2<-xx*eta_hat
  
  
  
  ######get xy1
  p0<-c()
  p1<-c()
  s<-function(a,b,c,p)
  {
    p1[1]<-(-b+p-a*p-a*c+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
    p1[2]<-(-b+p-a*p-a*c-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
    p0[1]<-(-a*p+p-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
    p0[2]<-(-a*p+p+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
    return(c(p0,p1))
  }
  u<-c()
  for (j in 1:r){
    temp<-s(exp(beta_m_hat[j]),(N-sum(y1[,j]))/N,sum(y1[,j])/1000,maf)
    u<-rbind(u,temp)
  }
  u<-u[,c(1,3)]
  a<-c()
  b<-c()
  c<-c()
  d<-c()
  e<-c()
  f<-c()
  for(j in 1:r)
  {
    a[j]<-(1-u[j,1])^2*(N-sum(y1[,j]))
    c[j]<-2*(1-u[j,1])*u[j,1]*(N-sum(y1[,j]))
    e[j]<-u[j,1]^2*(N-sum(y1[,j]))
    
    b[j]<-(1-u[j,2])^2*(sum(y1[,j]))
    d[j]<-2*(1-u[j,2])*u[j,2]*(sum(y1[,j]))
    f[j]<-u[j,2]^2*(sum(y1[,j]))
  }
  est<-cbind(a,c,e,b,d,f)
  est_cov<-c()
  true_cov<-c()
  
  for(j in 1:r)
  {
    est_cov[j]<-1/N*(est[j,1]*(2*maf)*(mean(y1[,j]))+est[j,2]*(1-2*maf)*(0-mean(y1[,j]))+est[j,3]*(2-2*maf)*(0-mean(y1[,j]))+est[j,4]*(0-2*maf)*(1-mean(y1[,j]))
                     +est[j,5]*(1-2*maf)*(1-mean(y1[,j]))+est[j,6]*(2-2*maf)*(1-mean(y1[,j])))
    
    true_cov[j]<-cov(x[,j],y1[,j])
  }
  
  xy1<-est_cov*N
  y1y2<-c()
  for(j in 1:r)
  {
    y1y2[j]<-cov(y1[j,],y2[,j])*N
  }
  
  
  if (method=='full'){
    
    var_beta_m_hat<-sd_beta_m_hat^2
    var_gamma_hat<-sd_gamma_hat^2
    beta_c<-c()
    
    pval_c<-c()
    var_c<-c()
    sd_c<-c()
    z<-c()
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),1),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,1),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
      beta_c[j]<-temp[1]
      var_c[j]<-(solve(v)%*%D%*%matrix(c(var_beta_m_hat[j],y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat[j]/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat[j]/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),var_gamma_hat[j]),nrow=2,ncol=2,byrow=F)%*%D%*%solve(v))[1,1]
      sd_c[j]<-sqrt(var_c[j])
      z[j]<-beta_c[j]/sqrt(var_c[j])
      pval_c[j]<-2*pnorm(-abs(z[j]))
      
    }
    
    print(mean(beta_c),na.rm=T)
    print(mean(sd_c),na.rm=T)
    print(mean(beta_hat),na.rm=T)
    print(mean(se),na.rm=T)
    
    png(paste0('y1bi_',maf,'_full','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    
    png(paste0('y1bi_',maf,'_full','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    print(mean(pval<0.05),na.rm=T)
    print(mean(pval_c<0.05),na.rm=T)
  }
  else if(method=='subset')
  {
    gamma_hat<-c()
    sd_gamma_hat<-c()
    for (j in 1:r){
      mod4<-glm(y1[1:200,j]~y2[1:200,j],family=binomial)
      gamma_hat[j]<-summary(mod4)$coefficients[2,1]
      sd_gamma_hat[j]<-summary(mod4)$coefficients[2,2]
    }
    
    var_beta_m_hat<-sd_beta_m_hat^2
    var_gamma_hat<-sd_gamma_hat^2
    beta_c<-c()
    
    pval_c<-c()
    var_c<-c()
    sd_c<-c()
    z<-c()
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),1),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,1),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
      beta_c[j]<-temp[1]
      var_c[j]<-(solve(v)%*%D%*%matrix(c(var_beta_m_hat[j],y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat[j]/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat[j]/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),var_gamma_hat[j]),nrow=2,ncol=2,byrow=F)%*%D%*%solve(v))[1,1]
      sd_c[j]<-sqrt(var_c[j])
      z[j]<-beta_c[j]/sqrt(var_c[j])
      pval_c[j]<-2*pnorm(-abs(z[j]))
      
    }
    
    print(mean(beta_c),na.rm=T)
    print(mean(sd_c),na.rm=T)
    png(paste0('y1bi_',maf,'_subset','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    png(paste0('y1bi_',maf,'_subset','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    print(mean(pval<0.05),na.rm=T)
    print(mean(pval_c<0.05),na.rm=T)
  }
  
  else if(method=="random")
  {
    beta_c<-c()
    
    pval_c<-c()
    var_c<-c()
    sd_c<-c()
    z<-c()
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      sd_gamma_hat<-runif(1,g_s*0.8,g_s*1.2)
      var_gamma_hat<-sd_gamma_hat^2
      v<-matrix(c(2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),eta_hat[j]*2*maf*(1-maf),y2y2[j]),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,y2y2[j]),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],runif(1,g*0.8,g*1.2))	
      beta_c[j]<-temp[1]
      var_c[j]<-(solve(v)%*%D%*%matrix(c(var_beta_m_hat[j],y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),y1y1[j]/N*eta_hat[j]*(y2y2[j])^(-1)*sd_beta_m_hat[j]*sd_gamma_hat/(sqrt((xx)^(-1)/(N-1)*(y1y1[j]-xy1[j]/xx*xy1[j])*(y2y2[j])^(-1)/(N-1)*(y1y1[j]-y1y2[j]/y2y2[j]*y1y2[j]))),var_gamma_hat),nrow=2,ncol=2,byrow=F)%*%D%*%solve(v))[1,1]
      z[j]<-beta_c[j]/sqrt(var_c[j])
      sd_c[j]<-sqrt(var_c[j])
      pval_c[j]<-2*pnorm(-abs(z[j]))
    }
    
    print(mean(beta_c),na.rm=T)
    print(mean(sd_c),na.rm=T)
    png(paste0('y1bi_',maf,'_random','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    png(paste0('y1bi_',maf,'_random','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    print(mean(pval<0.05),na.rm=T)
    print(mean(pval_c<0.05),na.rm=T)
  }
  
  
}

y1binary(p2=0.0,p1=0.08,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='random')


y1binary(p2=0.0,p1=0.08,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='random')

y1binary(p2=0.0,p1=0.08,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='full')
y1binary(p2=0.0,p1=0.08,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='subset')
y1binary(p2=0.0,p1=0.08,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='random')




