##################################################
#Peitao Wu (peitaowu@bu.edu)
#Biqi Wang (wangbiqi@bu.edu)
##################################################

#################function for simulation when y1 is continuous and y2 is binary y1~y2+snp
#######p1 proportion of variation explained by snp in y1~snp
#######p2 proportion of variation explained by snp in y2~snp
#######p21 proportion of variation explained by y2 in y1~y2
#######N sample size
#######r number of replicates
#######maf Minor allele frequency of snp
#######method, either full, subset or random (literature)
#######f0 P(Y2=1|Snp=0)
#######f1 P(Y2=1|Snp=1)
#######f2 P(Y2=1|Snp=2)

y2binary<-function(p2,p1,p21,N,r,f0,f1,f2,maf,method){
set.seed(23)
x<-matrix(rep(rbinom(N,2,maf),r),N,r)

####get Y_2
y2<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
           dimnames = NULL) 

for (j in 1:r){
  for (i in 1:N){
    y2[i,j]<-ifelse(x[i,j]==0,ifelse(runif(1,0,1)<=f0,1,0),ifelse(x[i,j]==1,ifelse(runif(1,0,1)<=f1,1,0),ifelse(runif(1,0,1)<=f2,1,0)))
  }
}

eta<-sqrt(p2*(var(y2[,1]))/(2*maf*(1-maf)))
beta_m<-sqrt(p1/(2*maf*(1-maf)))
gamma<-sqrt(p21/(sum(y2)/(N*r)*(1-sum(y2)/(N*r)))) 

epsilon<-matrix(data = NA, nrow = N, ncol =r, byrow = FALSE,
                dimnames = NULL)
for (j in 1:r)
{epsilon[,j]<-rnorm(N,0,sqrt(1-p1-p21))}

y1<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
           dimnames = NULL)      
for(j in 1:r)
{y1[,j]<-beta_m*x[,j]+gamma*y2[,j]+epsilon[,j]}



beta_m_hat<-c()
var_beta_m_hat<-c()
for(j in 1:r){
mod1<-lm(y1[,j]~x[,j])
beta_m_hat[j]<-summary(mod1)$coefficients[2,1]
var_beta_m_hat[j]<-(summary(mod1)$coefficients[2,2])^2
}

eta_hat<-c()
for(j in 1:r){
  mod2<-glm(y2[,j]~x[,j],family=binomial)
  eta_hat[j]<-summary(mod2)$coefficients[2,1]
}

beta_hat<-c()
se<-c()
pval<-c()
for(j in 1:r){
  mod3<-lm(y1[,j]~x[,j]+y2[,j])
  beta_hat[j]<-summary(mod3)$coefficients[2,1]
  se[j]<-summary(mod3)$coefficients[2,2]
  pval[j]<-summary(mod3)$coefficients[2,4]
}



#####
p0<-c()
p1<-c()
s<-function(a,b,c,p)
{
  p1[1]<-(-b+p-a*p-a*c+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
  p1[2]<-(-b+p-a*p-a*c-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
  p0[1]<-(-a*p+p-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
  p0[2]<-(-a*p+p+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
  return(c(p0,p1))
}
u<-c()
for (j in 1:r){
temp<-s(exp(eta_hat[j]),(N-sum(y2[,j]))/N,sum(y2[,j])/1000,maf)
u<-rbind(u,temp)
}
u<-u[,c(1,3)]
a<-c()
b<-c()
c<-c()
d<-c()
e<-c()
f<-c()
for(j in 1:r)
{
  a[j]<-(1-u[j,1])^2*(N-sum(y2[,j]))
  c[j]<-2*(1-u[j,1])*u[j,1]*(N-sum(y2[,j]))
  e[j]<-u[j,1]^2*(N-sum(y2[,j]))
  
  b[j]<-(1-u[j,2])^2*(sum(y2[,j]))
  d[j]<-2*(1-u[j,2])*u[j,2]*(sum(y2[,j]))
  f[j]<-u[j,2]^2*(sum(y2[,j]))
}
est<-cbind(a,c,e,b,d,f)
est_cov<-c()
true_cov<-c()

for(j in 1:r)
{
  est_cov[j]<-1/N*(est[j,1]*(2*maf)*(mean(y2[,j]))+est[j,2]*(1-2*maf)*(0-mean(y2[,j]))+est[j,3]*(2-2*maf)*(0-mean(y2[,j]))+est[j,4]*(0-2*maf)*(1-mean(y2[,j]))
                      +est[j,5]*(1-2*maf)*(1-mean(y2[,j]))+est[j,6]*(2-2*maf)*(1-mean(y2[,j])))
  
  true_cov[j]<-cov(x[,j],y2[,j])
}

#plot(est_cov,true_cov)
#abline(0,1,col='blue',lwd=2)

######full data
gamma_hat<-c()
for (j in 1:r){
  mod4<-lm(y1[,j]~y2[,j])
  gamma_hat[j]<-summary(mod4)$coefficients[2,1]
}

g<-mean(gamma_hat)

if (method=='full'){
gamma_hat<-c()
for (j in 1:r){
  mod4<-lm(y1[,j]~y2[,j])
  gamma_hat[j]<-summary(mod4)$coefficients[2,1]
}
	
#beta_c<-c()

beta_c<-c()
pval_c<-c()
sd_c<-c()
z<-c()
beta_c2<-c()
y1y1<-c()
y2y2<-c()
sigma_j<-c()

for(j in 1:r)
{#d<-cbind(x[,j],y2[,j])
  #v<-t(d)%*%d
  v<-matrix(c(2*maf*(1-maf),est_cov[j],est_cov[j],var(y2[,j])),nrow=2,ncol=2,byrow=F)
  D<-matrix(c(2*maf*(1-maf),0,0,var(y2[,j])),nrow=2,ncol=2,byrow=F)
  temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
 
beta_c[j]<-temp[1]
beta_c2[j]<-temp[2]
y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*N*var(y2[,j])*gamma_hat[j])
sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
#sd_c[j]<-sqrt(1/(N-1)*(solve(v)*var(y1[,j]))[1,1])
  z[j]<-beta_c[j]/sd_c[j]
  pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
  
  
}
print(mean(beta_c))
print(mean(sd_c))
print(mean(beta_hat))
print(mean(se))
png(paste0('y2bi_',maf,'_full','_beta','.png'))
plot(beta_c,beta_hat)
dev.off()

png(paste0('y2bi_',maf,'_full','_p','.png'))
plot(-log(pval_c,base=10),-log(pval,base=10))
abline(0,1)
dev.off()
print(mean(y2))
}
else if (method=='subset'){
	gamma_hat<-c()
for (j in 1:r){
  mod4<-lm(y1[1:200,j]~y2[1:200,j])
  gamma_hat[j]<-summary(mod4)$coefficients[2,1]
}

beta_c<-c()
pval_c<-c()
sd_c<-c()
z<-c()
beta_c2<-c()
y1y1<-c()
y2y2<-c()
sigma_j<-c()

for(j in 1:r)
{#d<-cbind(x[,j],y2[,j])
  #v<-t(d)%*%d
  v<-matrix(c(2*maf*(1-maf),est_cov[j],est_cov[j],var(y2[,j])),nrow=2,ncol=2,byrow=F)
  D<-matrix(c(2*maf*(1-maf),0,0,var(y2[,j])),nrow=2,ncol=2,byrow=F)
  temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
 
beta_c[j]<-temp[1]
beta_c2[j]<-temp[2]
y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*N*var(y2[,j])*gamma_hat[j])
sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
#sd_c[j]<-sqrt(1/(N-1)*(solve(v)*var(y1[,j]))[1,1])
  z[j]<-beta_c[j]/sd_c[j]
  pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
 
}
print(mean(beta_c))
print(mean(sd_c))

png(paste0('y2bi_',maf,'_subset','_beta','.png'))
plot(beta_c,beta_hat)
dev.off()
png(paste0('y2bi_',maf,'_subset','_p','.png'))
plot(-log(pval_c,base=10),-log(pval,base=10))
abline(0,1)
dev.off()

}
else if (method=='random')
{
beta_c<-c()
pval_c<-c()
sd_c<-c()
z<-c()
beta_c2<-c()
y1y1<-c()
y2y2<-c()
sigma_j<-c()

for(j in 1:r)
{#d<-cbind(x[,j],y2[,j])
  #v<-t(d)%*%d
  gamma_hat<-runif(1,g*0.8,g*1.2)
  v<-matrix(c(2*maf*(1-maf),est_cov[j],est_cov[j],var(y2[,j])),nrow=2,ncol=2,byrow=F)
  D<-matrix(c(2*maf*(1-maf),0,0,var(y2[,j])),nrow=2,ncol=2,byrow=F)
  temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat)	
 
beta_c[j]<-temp[1]
beta_c2[j]<-temp[2]
y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*N*var(y2[,j])*gamma_hat)
sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
#sd_c[j]<-sqrt(1/(N-1)*(solve(v)*var(y1[,j]))[1,1])
  z[j]<-beta_c[j]/sd_c[j]
  pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
  
  
}
print(mean(beta_c))

print(mean(sd_c))	
png(paste0('y2bi_',maf,'_random','_beta','.png'))
plot(beta_c,beta_hat)
dev.off()
png(paste0('y2bi_',maf,'_random','_p','.png'))
plot(-log(pval_c,base=10),-log(pval,base=10))
abline(0,1)
dev.off()
}

}

setwd("~/Google Drive/conditional analysis/newsimulation_10")
y2binary(p2=0.04,p1=0.02,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='full')
y2binary(p2=0.04,p1=0.02,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='subset')
y2binary(p2=0.04,p1=0.02,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='random')


setwd("~/Google Drive/conditional analysis/newsimulation_10/0.02")
y2binary(p2=0.04,p1=0.02,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='full')
y2binary(p2=0.04,p1=0.02,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='subset')
y2binary(p2=0.04,p1=0.02,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='random')



y2binary(p2=0.04,p1=0.02,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='full')
y2binary(p2=0.04,p1=0.02,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='subset')
y2binary(p2=0.04,p1=0.02,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='random')






#######type 1 error


y2binary<-function(p2,p1,p21,N,r,f0,f1,f2,maf,method){
  set.seed(23)
  x<-matrix(rep(rbinom(N,2,maf),r),N,r)
  
  ####get Y_2
  # y2<-matrix(data = rbinom(N*r,1,0.12), nrow = N, ncol = r, byrow = FALSE,
  #            dimnames = NULL) 
  # 
  for (j in 1:r){
    for (i in 1:N){
      y2[i,j]<-ifelse(x[i,j]==0,ifelse(runif(1,0,1)<=f0,1,0),ifelse(x[i,j]==1,ifelse(runif(1,0,1)<=f1,1,0),ifelse(runif(1,0,1)<=f2,1,0)))
    }
  }
  
  #eta<-sqrt(p2*(var(y2[,1]))/(2*maf*(1-maf)))
  beta_m<-sqrt(p1/(2*maf*(1-maf)))
  gamma<-sqrt(p21/(sum(y2)/(N*r)*(1-sum(y2)/(N*r)))) 
  
  epsilon<-matrix(data = NA, nrow = N, ncol =r, byrow = FALSE,
                  dimnames = NULL)
  for (j in 1:r)
  {epsilon[,j]<-rnorm(N,0,sqrt(1-p1-p21))}
  
  y1<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
             dimnames = NULL)      
  for(j in 1:r)
  {y1[,j]<-beta_m*x[,j]+gamma*y2[,j]+epsilon[,j]}
  
  
  
  beta_m_hat<-c()
  var_beta_m_hat<-c()
  for(j in 1:r){
    mod1<-lm(y1[,j]~x[,j])
    beta_m_hat[j]<-summary(mod1)$coefficients[2,1]
    var_beta_m_hat[j]<-(summary(mod1)$coefficients[2,2])^2
  }
  
  eta_hat<-c()
  for(j in 1:r){
    mod2<-glm(y2[,j]~x[,j],family=binomial)
    eta_hat[j]<-summary(mod2)$coefficients[2,1]
  }
  
  beta_hat<-c()
  se<-c()
  pval<-c()
  for(j in 1:r){
    mod3<-lm(y1[,j]~x[,j]+y2[,j])
    beta_hat[j]<-summary(mod3)$coefficients[2,1]
    se[j]<-summary(mod3)$coefficients[2,2]
    pval[j]<-summary(mod3)$coefficients[2,4]
  }
  
  
  
  #####
  p0<-c()
  p1<-c()
  s<-function(a,b,c,p)
  {
    p1[1]<-(-b+p-a*p-a*c+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
    p1[2]<-(-b+p-a*p-a*c-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
    p0[1]<-(-a*p+p-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
    p0[2]<-(-a*p+p+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
    return(c(p0,p1))
  }
  u<-c()
  for (j in 1:r){
    temp<-s(exp(eta_hat[j]),(N-sum(y2[,j]))/N,sum(y2[,j])/1000,maf)
    u<-rbind(u,temp)
  }
  u<-u[,c(1,3)]
  a<-c()
  b<-c()
  c<-c()
  d<-c()
  e<-c()
  f<-c()
  for(j in 1:r)
  {
    a[j]<-(1-u[j,1])^2*(N-sum(y2[,j]))
    c[j]<-2*(1-u[j,1])*u[j,1]*(N-sum(y2[,j]))
    e[j]<-u[j,1]^2*(N-sum(y2[,j]))
    
    b[j]<-(1-u[j,2])^2*(sum(y2[,j]))
    d[j]<-2*(1-u[j,2])*u[j,2]*(sum(y2[,j]))
    f[j]<-u[j,2]^2*(sum(y2[,j]))
  }
  est<-cbind(a,c,e,b,d,f)
  est_cov<-c()
  true_cov<-c()
  
  for(j in 1:r)
  {
    est_cov[j]<-1/N*(est[j,1]*(2*maf)*(mean(y2[,j]))+est[j,2]*(1-2*maf)*(0-mean(y2[,j]))+est[j,3]*(2-2*maf)*(0-mean(y2[,j]))+est[j,4]*(0-2*maf)*(1-mean(y2[,j]))
                     +est[j,5]*(1-2*maf)*(1-mean(y2[,j]))+est[j,6]*(2-2*maf)*(1-mean(y2[,j])))
    
    true_cov[j]<-cov(x[,j],y2[,j])
  }
  
  #plot(est_cov,true_cov)
  #abline(0,1,col='blue',lwd=2)
  
  ######full data
  gamma_hat<-c()
  for (j in 1:r){
    mod4<-lm(y1[,j]~y2[,j])
    gamma_hat[j]<-summary(mod4)$coefficients[2,1]
  }
  
  g<-mean(gamma_hat)
  
  if (method=='full'){
    gamma_hat<-c()
    for (j in 1:r){
      mod4<-lm(y1[,j]~y2[,j])
      gamma_hat[j]<-summary(mod4)$coefficients[2,1]
    }
    
    #beta_c<-c()
    
    beta_c<-c()
    pval_c<-c()
    sd_c<-c()
    z<-c()
    beta_c2<-c()
    y1y1<-c()
    y2y2<-c()
    sigma_j<-c()
    
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      v<-matrix(c(2*maf*(1-maf),est_cov[j],est_cov[j],var(y2[,j])),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,var(y2[,j])),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
      
      beta_c[j]<-temp[1]
      beta_c2[j]<-temp[2]
      y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
      sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*N*var(y2[,j])*gamma_hat[j])
      sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
      #sd_c[j]<-sqrt(1/(N-1)*(solve(v)*var(y1[,j]))[1,1])
      z[j]<-beta_c[j]/sd_c[j]
      pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
      
      
    }
    print(mean(beta_c))
    print(mean(sd_c))
    print(mean(beta_hat))
    print(mean(se))
    png(paste0('y2bi_',maf,'_full','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    
    png(paste0('y2bi_',maf,'_full','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    #print(mean(y2))
    print(mean(pval<0.05))
    print(mean(pval_c<0.05))
  }
  else if (method=='subset'){
    gamma_hat<-c()
    for (j in 1:r){
      mod4<-lm(y1[1:200,j]~y2[1:200,j])
      gamma_hat[j]<-summary(mod4)$coefficients[2,1]
    }
    
    beta_c<-c()
    pval_c<-c()
    sd_c<-c()
    z<-c()
    beta_c2<-c()
    y1y1<-c()
    y2y2<-c()
    sigma_j<-c()
    
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      v<-matrix(c(2*maf*(1-maf),est_cov[j],est_cov[j],var(y2[,j])),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,var(y2[,j])),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
      
      beta_c[j]<-temp[1]
      beta_c2[j]<-temp[2]
      y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
      sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*N*var(y2[,j])*gamma_hat[j])
      sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
      #sd_c[j]<-sqrt(1/(N-1)*(solve(v)*var(y1[,j]))[1,1])
      z[j]<-beta_c[j]/sd_c[j]
      pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
      
    }
    print(mean(beta_c))
    print(mean(sd_c))
    
    png(paste0('y2bi_',maf,'_subset','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    png(paste0('y2bi_',maf,'_subset','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    print(mean(pval<0.05))
    print(mean(pval_c<0.05))
  }
  else if (method=='random')
  {
    beta_c<-c()
    pval_c<-c()
    sd_c<-c()
    z<-c()
    beta_c2<-c()
    y1y1<-c()
    y2y2<-c()
    sigma_j<-c()
    
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      gamma_hat<-runif(1,g*0.8,g*1.2)
      v<-matrix(c(2*maf*(1-maf),est_cov[j],est_cov[j],var(y2[,j])),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,var(y2[,j])),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat)	
      
      beta_c[j]<-temp[1]
      beta_c2[j]<-temp[2]
      y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
      sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*N*var(y2[,j])*gamma_hat)
      sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
      #sd_c[j]<-sqrt(1/(N-1)*(solve(v)*var(y1[,j]))[1,1])
      z[j]<-beta_c[j]/sd_c[j]
      pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
      
      
    }
    print(mean(beta_c))
    
    print(mean(sd_c))	
    png(paste0('y2bi_',maf,'_random','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    png(paste0('y2bi_',maf,'_random','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    print(mean(pval<0.05))
    print(mean(pval_c<0.05))
  }
  
}

###snp unasso trait and cov

y2binary(p2=0.04,p1=0.00,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='full')
y2binary(p2=0.04,p1=0.00,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='subset')
y2binary(p2=0.04,p1=0.00,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='random')

y2binary(p2=0.04,p1=0.00,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='full')
y2binary(p2=0.04,p1=0.00,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='subset')
y2binary(p2=0.04,p1=0.00,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.10,method='random')

y2binary(p2=0.04,p1=0.00,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='full')
y2binary(p2=0.04,p1=0.00,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='subset')
y2binary(p2=0.04,p1=0.00,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='random')

y2binary(p2=0.04,p1=0.00,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='full')
y2binary(p2=0.04,p1=0.00,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='subset')
y2binary(p2=0.04,p1=0.00,p21=0.02,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='random')





#####power
y2binary<-function(p2,p1,p21,N,r,f0,f1,f2,maf,method){
  set.seed(23)
  x<-matrix(rep(rbinom(N,2,maf),r),N,r)
  
  y2<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
             dimnames = NULL) 
  y2<-matrix(data = rbinom(N*r,1,0.12), nrow = N, ncol = r, byrow = FALSE,
             dimnames = NULL) 
  
  #eta<-sqrt(p2*(var(y2[,1]))/(2*maf*(1-maf)))
  beta_m<-sqrt(p1/(2*maf*(1-maf)))
  gamma<-sqrt(p21/(sum(y2)/(N*r)*(1-sum(y2)/(N*r)))) 
  
  epsilon<-matrix(data = NA, nrow = N, ncol =r, byrow = FALSE,
                  dimnames = NULL)
  for (j in 1:r)
  {epsilon[,j]<-rnorm(N,0,sqrt(1-p1-p21))}
  
  y1<-matrix(data = NA, nrow = N, ncol = r, byrow = FALSE,
             dimnames = NULL)      
  for(j in 1:r)
  {y1[,j]<-beta_m*x[,j]+gamma*y2[,j]+epsilon[,j]}
  
  
  
  beta_m_hat<-c()
  var_beta_m_hat<-c()
  for(j in 1:r){
    mod1<-lm(y1[,j]~x[,j])
    beta_m_hat[j]<-summary(mod1)$coefficients[2,1]
    var_beta_m_hat[j]<-(summary(mod1)$coefficients[2,2])^2
  }
  
  eta_hat<-c()
  for(j in 1:r){
    mod2<-glm(y2[,j]~x[,j],family=binomial)
    eta_hat[j]<-summary(mod2)$coefficients[2,1]
  }
  
  beta_hat<-c()
  se<-c()
  pval<-c()
  for(j in 1:r){
    mod3<-lm(y1[,j]~x[,j]+y2[,j])
    beta_hat[j]<-summary(mod3)$coefficients[2,1]
    se[j]<-summary(mod3)$coefficients[2,2]
    pval[j]<-summary(mod3)$coefficients[2,4]
  }
  
  
  
  #####
  p0<-c()
  p1<-c()
  s<-function(a,b,c,p)
  {
    p1[1]<-(-b+p-a*p-a*c+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
    p1[2]<-(-b+p-a*p-a*c-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2))/(2*(c-a*c))
    p0[1]<-(-a*p+p-sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
    p0[2]<-(-a*p+p+sqrt(a^2*p^2-2*a^2*c*p+a^2*c^2+2*a*b*p+2*a*b*c-2*a*p^2+2*a*c*p+b^2-2*b*p+p^2)+a*c+b)/(2*b*(1-a))
    return(c(p0,p1))
  }
  u<-c()
  for (j in 1:r){
    temp<-s(exp(eta_hat[j]),(N-sum(y2[,j]))/N,sum(y2[,j])/1000,maf)
    u<-rbind(u,temp)
  }
  u<-u[,c(1,3)]
  a<-c()
  b<-c()
  c<-c()
  d<-c()
  e<-c()
  f<-c()
  for(j in 1:r)
  {
    a[j]<-(1-u[j,1])^2*(N-sum(y2[,j]))
    c[j]<-2*(1-u[j,1])*u[j,1]*(N-sum(y2[,j]))
    e[j]<-u[j,1]^2*(N-sum(y2[,j]))
    
    b[j]<-(1-u[j,2])^2*(sum(y2[,j]))
    d[j]<-2*(1-u[j,2])*u[j,2]*(sum(y2[,j]))
    f[j]<-u[j,2]^2*(sum(y2[,j]))
  }
  est<-cbind(a,c,e,b,d,f)
  est_cov<-c()
  true_cov<-c()
  
  for(j in 1:r)
  {
    est_cov[j]<-1/N*(est[j,1]*(2*maf)*(mean(y2[,j]))+est[j,2]*(1-2*maf)*(0-mean(y2[,j]))+est[j,3]*(2-2*maf)*(0-mean(y2[,j]))+est[j,4]*(0-2*maf)*(1-mean(y2[,j]))
                     +est[j,5]*(1-2*maf)*(1-mean(y2[,j]))+est[j,6]*(2-2*maf)*(1-mean(y2[,j])))
    
    true_cov[j]<-cov(x[,j],y2[,j])
  }
  
  #plot(est_cov,true_cov)
  #abline(0,1,col='blue',lwd=2)
  
  ######full data
  gamma_hat<-c()
  for (j in 1:r){
    mod4<-lm(y1[,j]~y2[,j])
    gamma_hat[j]<-summary(mod4)$coefficients[2,1]
  }
  
  g<-mean(gamma_hat)
  
  if (method=='full'){
    gamma_hat<-c()
    for (j in 1:r){
      mod4<-lm(y1[,j]~y2[,j])
      gamma_hat[j]<-summary(mod4)$coefficients[2,1]
    }
    
    #beta_c<-c()
    
    beta_c<-c()
    pval_c<-c()
    sd_c<-c()
    z<-c()
    beta_c2<-c()
    y1y1<-c()
    y2y2<-c()
    sigma_j<-c()
    
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      v<-matrix(c(2*maf*(1-maf),est_cov[j],est_cov[j],var(y2[,j])),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,var(y2[,j])),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
      
      beta_c[j]<-temp[1]
      beta_c2[j]<-temp[2]
      y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
      sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*N*var(y2[,j])*gamma_hat[j])
      sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
      #sd_c[j]<-sqrt(1/(N-1)*(solve(v)*var(y1[,j]))[1,1])
      z[j]<-beta_c[j]/sd_c[j]
      pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
      
      
    }
    print(mean(beta_c))
    print(mean(sd_c))
    print(mean(beta_hat))
    print(mean(se))
    png(paste0('y2bi_',maf,'_full','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    
    png(paste0('y2bi_',maf,'_full','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    #print(mean(y2))
    print(mean(pval<0.05))
    print(mean(pval_c<0.05))
  }
  else if (method=='subset'){
    gamma_hat<-c()
    for (j in 1:r){
      mod4<-lm(y1[1:200,j]~y2[1:200,j])
      gamma_hat[j]<-summary(mod4)$coefficients[2,1]
    }
    
    beta_c<-c()
    pval_c<-c()
    sd_c<-c()
    z<-c()
    beta_c2<-c()
    y1y1<-c()
    y2y2<-c()
    sigma_j<-c()
    
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      v<-matrix(c(2*maf*(1-maf),est_cov[j],est_cov[j],var(y2[,j])),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,var(y2[,j])),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat[j])	
      
      beta_c[j]<-temp[1]
      beta_c2[j]<-temp[2]
      y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
      sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*N*var(y2[,j])*gamma_hat[j])
      sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
      #sd_c[j]<-sqrt(1/(N-1)*(solve(v)*var(y1[,j]))[1,1])
      z[j]<-beta_c[j]/sd_c[j]
      pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
      
    }
    print(mean(beta_c))
    print(mean(sd_c))
    
    png(paste0('y2bi_',maf,'_subset','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    png(paste0('y2bi_',maf,'_subset','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    print(mean(pval<0.05))
    print(mean(pval_c<0.05))
  }
  else if (method=='random')
  {
    beta_c<-c()
    pval_c<-c()
    sd_c<-c()
    z<-c()
    beta_c2<-c()
    y1y1<-c()
    y2y2<-c()
    sigma_j<-c()
    
    for(j in 1:r)
    {#d<-cbind(x[,j],y2[,j])
      #v<-t(d)%*%d
      gamma_hat<-runif(1,g*0.8,g*1.2)
      v<-matrix(c(2*maf*(1-maf),est_cov[j],est_cov[j],var(y2[,j])),nrow=2,ncol=2,byrow=F)
      D<-matrix(c(2*maf*(1-maf),0,0,var(y2[,j])),nrow=2,ncol=2,byrow=F)
      temp<-solve(v)%*%D%*%c(beta_m_hat[j],gamma_hat)	
      
      beta_c[j]<-temp[1]
      beta_c2[j]<-temp[2]
      y1y1[j]<-(N-1)*N*2*maf*(1-maf)*var_beta_m_hat[j]+N*2*maf*(1-maf)*(beta_m_hat[j])^2
      sigma_j[j]<-1/(N-2)*(y1y1[j]-beta_c[j]*beta_m_hat[j]*N*2*maf*(1-maf)-beta_c2[j]*N*var(y2[,j])*gamma_hat)
      sd_c[j]<-sqrt(1/(N-1)*(solve(v)*sigma_j[j])[1,1])
      #sd_c[j]<-sqrt(1/(N-1)*(solve(v)*var(y1[,j]))[1,1])
      z[j]<-beta_c[j]/sd_c[j]
      pval_c[j]<-2*pt(-abs(z[j]),df=N-3)
      
      
    }
    print(mean(beta_c))
    
    print(mean(sd_c))	
    png(paste0('y2bi_',maf,'_random','_beta','.png'))
    plot(beta_c,beta_hat)
    dev.off()
    png(paste0('y2bi_',maf,'_random','_p','.png'))
    plot(-log(pval_c,base=10),-log(pval,base=10))
    abline(0,1)
    dev.off()
    print(mean(pval<0.05))
    print(mean(pval_c<0.05))
  }
  
}



y2binary(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='random')

y2binary(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='random')

y2binary(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='random')

y2binary(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.25,method='random')



y2binary(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='random')

y2binary(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='random')

y2binary(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='random')

y2binary(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.1,method='random')


y2binary(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='random')

y2binary(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='random')

y2binary(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='random')

y2binary(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.05,method='random')


y2binary(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.05,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='random')

y2binary(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.1,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='random')

y2binary(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.2,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='random')

y2binary(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='full')
y2binary(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='subset')
y2binary(p2=0.0,p1=0.01,p21=0.4,N=1000,r=1000,f0=0.1,f1=0.2,f2=0.4,maf=0.02,method='random')










